# Urls
API_URL = 'https://stockx.com/api'
ALGOLIA_URL = (
    "https://xw7sbct9v6-1.algolianet.com/1/indexes/products/query?x-algolia-agent=Algolia%20for%20vanilla"
    "%20JavaScript%203.32.1&x-algolia-application-id=XW7SBCT9V6&x-algolia-api-key"
    "=6b5e76b49705eb9f51a06d3c82f7acee "
)

# End points
GET_PRODUCT = f'{API_URL}/products'
SEARCH_PRODUCTS = f'{API_URL}/browse'
CHART_DATA = 'chart'
SOLD_DATA = 'activity'

# Limits
SOLD_DATA_LIMIT = 250

# States
SOLD_STATE = 480
